@@ -5,7 +5,6 @@ import time
 import signal
 import asyncio
 import threading
-from functools import wraps
 from itertools import chain
 from collections import defaultdict
 from typing import (
@@ -45,6 +44,7 @@ from alicebot.utils import (
     ModulePathFinder,
     samefile,
     get_module_name,
+    sync_func_wrapper,
     load_module_from_name,
     load_modules_from_dir,
 )
@@ -64,20 +64,18 @@ class Bot:
     Attributes:
         config: 机器人配置。
         should_exit: 机器人是否应该进入准备退出状态。
-        adapters: 适配器列表。
         plugins_priority_dict: 插件优先级字典。
         plugin_state: 插件状态。
         global_state: 全局状态。
     """
 
     config: MainConfig
-
     should_exit: asyncio.Event
-    adapters: List[Adapter]
     plugins_priority_dict: Dict[int, List[ModuleInfo]]
     plugin_state: Dict[str, Any]
     global_state: Dict[Any, Any]
 
+    _adapters: List[Tuple[Adapter, ModuleInfo]]  # 适配器和适配器信息列表
     _condition: asyncio.Condition  # 用于处理 get 的 Condition
     _current_event: T_Event  # 当前待处理的 Event
 
@@ -119,12 +117,11 @@ class Bot:
                 启用后将自动检查 `plugin_dir` 中的插件文件更新，并在更新时自动重新加载。
         """
         self.config = MainConfig()
-
-        self.adapters = []
         self.plugins_priority_dict = defaultdict(list)
         self.plugin_state = defaultdict(type(None))
         self.global_state = {}
 
+        self._adapters = []
         self._restart_flag = False
         self._module_path_finder = ModulePathFinder()
         self._raw_config_dict = {}
@@ -157,6 +154,11 @@ class Bot:
             )
         )
 
+    @property
+    def adapters(self) -> List[Adapter]:
+        """当前已经加载的适配器的列表。"""
+        return list(map(lambda x: x[0], self._adapters))
+
     def run(self):
         """运行 AliceBot，监听并拦截系统退出信号，更新机器人配置。"""
         self._restart_flag = True
@@ -236,7 +238,7 @@ class Bot:
             await _hook_func(self)
 
         try:
-            for _adapter in self.adapters:
+            for _adapter, _ in self._adapters:
                 for _hook_func in self._adapter_startup_hooks:
                     await _hook_func(_adapter)
                 try:
@@ -248,7 +250,7 @@ class Bot:
                         self.config.verbose_exception_log,
                     )
 
-            for _adapter in self.adapters:
+            for _adapter, _ in self._adapters:
                 for _hook_func in self._adapter_run_hooks:
                     await _hook_func(_adapter)
                 asyncio.create_task(_adapter.safe_run())
@@ -258,18 +260,27 @@ class Bot:
             if hot_reload_task is not None:
                 await hot_reload_task
         finally:
-            for _adapter in self.adapters:
+            for _adapter, _ in self._adapters:
                 for _hook_func in self._adapter_shutdown_hooks:
                     await _hook_func(_adapter)
                 await _adapter.shutdown()
             for _hook_func in self._bot_exit_hooks:
                 _hook_func(self)
 
-            self.adapters.clear()
+            self._adapters.clear()
             self.plugins_priority_dict.clear()
             self._config_update_dict.clear()
             self._module_path_finder.path.clear()
 
+    def _remove_plugin_by_path(self, file: str) -> Optional[ModuleInfo]:
+        for plugins in self.plugins_priority_dict.values():
+            for i, _plugin in enumerate(plugins):
+                if samefile(getattr(_plugin.module, "__file__", None), file):
+                    plugins.pop(i)
+                    self._remove_config_module(_plugin.config_class)
+                    return _plugin
+        return None
+
     async def _run_hot_reload(self):
         """热重载。"""
         try:
@@ -335,53 +346,49 @@ class Bot:
                         )
                     else:
                         logger.info(
-                            f"Succeeded to add new plugin "
-                            f'"{plugin_info.module_class.__name__}" '
-                            f'from file "{file}"'
+                            "Succeeded to add new plugin "
+                            f'"{plugin_info.module_class.__name__}" from file "{file}"'
                         )
                     continue
-                for plugins in self.plugins_priority_dict.values():
-                    for i, _plugin in enumerate(plugins):
-                        if samefile(getattr(_plugin.module, "__file__", None), file):
-                            if change_type == Change.modified:
-                                try:
-                                    self._remove_config_module(_plugin.config_class)
-                                    plugins.pop(i)
-                                    plugin_info = load_module_from_name(
-                                        _plugin.module.__name__, Plugin
-                                    )
-                                    self._load_plugin_module(plugin_info)
-                                    self._reload_config()
-                                except Exception as e:
-                                    error_or_exception(
-                                        f'Reload plugin from file "{file}" failed:',
-                                        e,
-                                        self.config.verbose_exception_log,
-                                    )
-                                else:
-                                    logger.info(
-                                        f"Succeeded to reload plugin "
-                                        f'"{_plugin.module_class.__name__}" '
-                                        f'from file "{file}"'
-                                    )
-                            elif change_type == Change.deleted:
-                                try:
-                                    plugins.pop(i)
-                                    self._remove_config_module(_plugin.config_class)
-                                    self._reload_config()
-                                except Exception as e:
-                                    error_or_exception(
-                                        f'Removed plugin from file "{file}" failed:',
-                                        e,
-                                        self.config.verbose_exception_log,
-                                    )
-                                else:
-                                    logger.info(
-                                        f"Succeeded to remove plugin "
-                                        f'"{_plugin.module_class.__name__}" '
-                                        f'from file "{file}"'
-                                    )
-                            break
+                elif change_type == Change.deleted:
+                    try:
+                        _plugin = self._remove_plugin_by_path(file)
+                        self._reload_config()
+                    except Exception as e:
+                        error_or_exception(
+                            f'Removed plugin from file "{file}" failed:',
+                            e,
+                            self.config.verbose_exception_log,
+                        )
+                    else:
+                        if _plugin is not None:
+                            logger.info(
+                                "Succeeded to remove plugin "
+                                f'"{_plugin.module_class.__name__}" from file "{file}"'
+                            )
+                elif change_type == Change.modified:
+                    msg = "reload"
+                    try:
+                        _plugin = self._remove_plugin_by_path(file)
+                        if _plugin is not None:
+                            plugin_module_name = _plugin.module.__name__
+                        else:
+                            msg = "add new"
+                            plugin_module_name = get_module_name(file)
+                        plugin_info = load_module_from_name(plugin_module_name, Plugin)
+                        self._load_plugin_module(plugin_info)
+                        self._reload_config()
+                    except Exception as e:
+                        error_or_exception(
+                            f'{msg.capitalize()} plugin from file "{file}" failed:',
+                            e,
+                            self.config.verbose_exception_log,
+                        )
+                    else:
+                        logger.info(
+                            f"Succeeded to {msg} plugin "
+                            f'"{plugin_info.module_class.__name__}" from file "{file}"'
+                        )
 
     def reload_plugins(self):
         """手动重新加载所有插件。"""
@@ -393,6 +400,8 @@ class Bot:
         self._load_plugins_from_dir(self._extend_plugin_dirs)
         for _plugin in self._extend_plugins:
             self._load_plugin(_plugin)
+        for _, adapter_info in self._adapters:
+            self._update_config_module(adapter_info.config_class)
         self._reload_config()
 
     def _handle_exit(self, *args):  # noqa
@@ -505,21 +514,10 @@ class Bot:
         Raises:
             GetEventTimeout: 超过最大事件数或超时。
         """
-
-        async def always_true(_):
-            return True
-
-        def async_wrapper(_func):
-            @wraps(_func)
-            async def _wrapper(_event):
-                return _func(_event)
-
-            return _wrapper
-
         if func is None:
-            func = always_true
+            func = sync_func_wrapper(lambda x: True)
         elif not asyncio.iscoroutinefunction(func):
-            func = async_wrapper(func)
+            func = sync_func_wrapper(func)
 
         try_times = 0
         start_time = time.time()
@@ -656,7 +654,7 @@ class Bot:
                 f'Load adapter "{name}" failed:', e, self.config.verbose_exception_log
             )
         else:
-            self.adapters.append(adapter_object)
+            self._adapters.append((adapter_object, adapter_info))
             self._update_config_module(adapter_info.config_class)
             logger.info(
                 f'Succeeded to load adapter "{adapter_info.module_class.__name__}" '
@@ -716,7 +714,7 @@ class Bot:
         Raises:
             LookupError: 找不到此名称的适配器对象。
         """
-        for _adapter in self.adapters:
+        for _adapter, _ in self._adapters:
             if _adapter.name == name:
                 return _adapter
         raise LookupError
