@@ -1,3 +1,8 @@
+"""AliceBot 类型提示支持。
+
+此模块定义了部分 AliceBot 使用的类型。
+"""
+
 from typing import TYPE_CHECKING, TypeVar, Callable, NoReturn, Awaitable
 
 from alicebot.message import T_MS, T_Message, T_MessageSegment
